@@ -13,15 +13,17 @@ obtain one at http://mozilla.org/MPL/2.0/.
 ----------------------------------------------------------------------------
 https://www.direct-netware.de/redirect?licenses;mpl2
 ----------------------------------------------------------------------------
-v2.0.0
+v2.1.1
 dpt_runtime/__init__.py
 """
 
 from .binary import Binary
 from .charset import Charset
 from .environment import Environment
+from .environment_dict import EnvironmentDict
 from .input_filter import InputFilter
 from .iterator import Iterator
 from .not_implemented_class import NotImplementedClass
+from .settings import Settings
 from .stacked_dict import StackedDict
 from .supports_mixin import SupportsMixin
